@@ -28,28 +28,27 @@ command = [repoCommand "initremote"
 	"sets up a special (non-git) remote"]
 
 seek :: [CommandSeek]
-seek = [withString start]
+seek = [withWords start]
 
-start :: CommandStartString
-start params = notBareRepo $ do
+start :: CommandStartWords
+start ws = notBareRepo $ do
 	when (null ws) $ error "Specify a name for the remote"
 
 	(u, c) <- findByName name
 	let fullconfig = M.union config c	
 	t <- findType fullconfig
-	
+
 	showStart "initremote" name
-	return $ Just $ perform t u $ M.union config c
+	next $ perform t u $ M.union config c
 
 	where
-		ws = words params
 		name = head ws
 		config = Remote.keyValToConfig $ tail ws
 
 perform :: RemoteClass.RemoteType Annex -> UUID -> RemoteClass.RemoteConfig -> CommandPerform
 perform t u c = do
 	c' <- RemoteClass.setup t u c
-	return $ Just $ cleanup u c'
+	next $ cleanup u c'
 
 cleanup :: UUID -> RemoteClass.RemoteConfig -> CommandCleanup
 cleanup u c = do
@@ -68,11 +67,11 @@ cleanup u c = do
 findByName :: String -> Annex (UUID, RemoteClass.RemoteConfig)
 findByName name = do
 	m <- Remote.readRemoteLog
-	case findByName' name m of
-		Just i -> return i
-		Nothing -> do
+	maybe generate return $ findByName' name m
+	where
+		generate = do
 			uuid <- liftIO $ genUUID
-			return $ (uuid, M.insert nameKey name M.empty)
+			return (uuid, M.insert nameKey name M.empty)
 
 findByName' :: String ->  M.Map UUID RemoteClass.RemoteConfig -> Maybe (UUID, RemoteClass.RemoteConfig)
 findByName' n m = if null matches then Nothing else Just $ head matches
@@ -86,12 +85,13 @@ findByName' n m = if null matches then Nothing else Just $ head matches
 
 {- find the specified remote type -}
 findType :: RemoteClass.RemoteConfig -> Annex (RemoteClass.RemoteType Annex)
-findType config = 
-	case M.lookup typeKey config of
-		Nothing -> error "Specify the type of remote with type="
-		Just s -> case filter (\i -> RemoteClass.typename i == s) Remote.remoteTypes of
+findType config = maybe unspecified specified $ M.lookup typeKey config
+	where
+		unspecified = error "Specify the type of remote with type="
+		specified s = case filter (findtype s) Remote.remoteTypes of
 			[] -> error $ "Unknown remote type " ++ s
 			(t:_) -> return t
+		findtype s i = RemoteClass.typename i == s
 
 {- The name of a configured remote is stored in its config using this key. -}
 nameKey :: String
