@@ -37,17 +37,12 @@ seek = [withNothing start]
 start :: CommandStartNothing
 start = notBareRepo $ do
 	showStart "unused" ""
-	return $ Just perform
+	next perform
 
 perform :: CommandPerform
 perform = do
-	from <- Annex.getState Annex.fromremote
-	case from of
-		Just name -> do
-			r <- Remote.byName name
-			checkRemoteUnused r
-		_ -> checkUnused
-	return $ Just $ return True
+	maybe checkUnused checkRemoteUnused =<< Annex.getState Annex.fromremote
+	next $ return True
 
 checkUnused :: Annex ()
 checkUnused = do
@@ -63,8 +58,11 @@ checkUnused = do
 			writeUnusedFile file unusedlist
 			return $ length l
 
-checkRemoteUnused :: Remote.Remote Annex -> Annex ()
-checkRemoteUnused r = do
+checkRemoteUnused :: String -> Annex ()
+checkRemoteUnused name = checkRemoteUnused' =<< Remote.byName name
+
+checkRemoteUnused' :: Remote.Remote Annex -> Annex ()
+checkRemoteUnused' r = do
 	g <- Annex.gitRepo
 	showNote $ "checking for unused data on " ++ Remote.name r ++ "..."
 	referenced <- getKeysReferenced
